summaryrefslogtreecommitdiffstats
path: root/src/mxcl.library.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mxcl.library.h')
-rw-r--r--src/mxcl.library.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mxcl.library.h b/src/mxcl.library.h
index feb71ef..87eea65 100644
--- a/src/mxcl.library.h
+++ b/src/mxcl.library.h
@@ -17,12 +17,12 @@ namespace mxcl
/// almost always negates the need to #include <klocale.h> in implementations
-#include <qstring.h>
-QString i18n( const char *text );
+#include <ntqstring.h>
+TQString i18n( const char *text );
-/// very useful for QStringLists
+/// very useful for TQStringLists
#define foreach( x ) \
- for( QStringList::ConstIterator it = x.constBegin(), end = x.constEnd(); it != end; ++it )
+ for( TQStringList::ConstIterator it = x.constBegin(), end = x.constEnd(); it != end; ++it )
#endif